
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {
}

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when reviving from ghost (optional)
	inst.components.locomotor:SetExternalSpeedMultiplier(inst, "ryuujou_speed_mod", 1)
end

local function onbecameghost(inst)
	-- Remove speed modifier when becoming a ghost
   inst.components.locomotor:RemoveExternalSpeedMultiplier(inst, "ryuujou_speed_mod")
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
    inst:ListenForEvent("ms_becameghost", onbecameghost)

    if inst:HasTag("playerghost") then
        onbecameghost(inst)
    else
        onbecamehuman(inst)
    end
end


-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "ryuujou.tex" )
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "willow"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(130)
	inst.components.hunger:SetMax(150)
	inst.components.sanity:SetMax(170)
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 0.90
	
	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 0.8 * TUNING.WILSON_HUNGER_RATE
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
	-- Dodge mechanic taken from http://steamcommunity.com/sharedfiles/filedetails/?id=612991019
		inst._GetAttacked = inst.components.combat.GetAttacked
		inst.components.combat.GetAttacked = function(attacker, damage, weapon, stimuli)
			if math.random() > .15 then
				inst._GetAttacked(attacker, damage, weapon, stimuli) 
			else
				inst.components.talker:Say(GetString(inst, "ANNOUNCE_AVOID"))
			end
	end

end



return MakePlayerCharacter("ryuujou", prefabs, assets, common_postinit, master_postinit, start_inv)
